import re
import unittest
import ir_datasets
from ir_datasets.datasets.highwire import HighwireDoc, HighwireSpan, HighwireQrel
from ir_datasets.formats import GenericQuery
from .base import DatasetIntegrationTest


_logger = ir_datasets.log.easy()


class TestHighwire(DatasetIntegrationTest):
    def test_highwire_docs(self):
        self._test_docs('highwire', count=162259, items={
            0: HighwireDoc('10901322', 'ajepidem', '\r\nJohn Snow and Modern-Day Environmental Epidemiology\r\n', (HighwireSpan(start=0, length=151, text='\r\n\r\n\r\nJohn Snow and Modern-Day Environmental Epidemiology\r\n\r\n\r\n\r\nDale P. Sandler\r\n'), HighwireSpan(start=154, length=207, text='\r\n\r\nFrom the Epidemiology Branch, National Institute of Environmental Health Sciences, P.O. Box 12233\x97Mail Drop A3-05, 111 T. W. Alexander Drive, Research Triangle Park, NC 27709.\r\n'), HighwireSpan(start=364, length=296, text='\r\n\r\n\r\n\r\n\r\nWhat does an anecdote about John Snow have to do with modern-day epidemiology? And why use it to introduce an issue of the Journal highlighting the challenges of studying disease risks associated with low dose environmental exposures? '), HighwireSpan(start=663, length=1494, text="\r\n\r\nIn this issue, Lilienfeld describes John Snow giving expert-witness testimony on behalf of industry (1). Besides being interesting on a historical basis, this incident raises several issues that are pertinent today. Lilienfeld's paper and the accompanying commentary by Vandenbroucke (2) deal directly or indirectly with the role and responsibilities of expert witnesses, the extrapolation of data on health effects from high dose exposures to low dose exposures, the importance of epidemiology to the development of public health policy, the current debates on environmental justice (3), and the use of the precautionary principle (4) in standard-setting. Furthermore, if faced with an issue similar to that faced by Snow\x97namely, local residents' being worried about health consequences associated with emanations from factories\x97would modern-day environmental epidemiologists be any better positioned to carry out appropriate studies and reach sound conclusions? "), HighwireSpan(start=2160, length=844, text='\r\n\r\nSnow can be seen at once as victim and perpetrator of sins that are common in epidemiology in general and in environmental epidemiology in particular. Was Snow victimized by the medical establishment, including The Lancet, for expressing views that were not commonly held by the scientists of the day? Were his peers outraged because of the reactionary social position he was taking (as suggested by Vandenbroucke)? On the other hand, was he as guilty as proponents of the miasma theory for trying to apply his theory of disease transmission to all situations without allowing for the possibility of multiple disease pathways? Did he fall into the trap of equating the absence of data with an absence of effect? '), HighwireSpan(start=3007, length=860, text='\r\n\r\nWhen Snow contended that emanations from the bone-boiling factories were not causing ill health in the community at large, he invoked arguments that are often raised when unexpected health effects are encountered following supposed low dose exposures. One argument is that such health effects are implausible given what we know about high dose exposures. In this instance, Snow noted that the factory workers were not dying and therefore health effects in the community at large were not plausible. A related argument is that, even if workers are dying or suffering other health effects, because of the distance from the exposure source, the exposure levels in the community are probably too low to plausibly affect health. '), HighwireSpan(start=3870, length=892, text='\r\n\r\nHealth effects of low dose exposures are often seen as implausible, even in the face of accumulated consistent evidence. Such arguments have frequently been invoked in environmental epidemiology. Examples of low dose exposures that have been deemed implausible contributors to disease risk based on what is known about high dose exposures include passive smoking, residential radon exposure, childhood lead exposure, electromagnetic fields, and residence near nuclear facilities. If one begins with a fixed idea of what is plausible, arguments regarding susceptible subgroups, inverse dose rate, hormesis, multiple pathways, multifactor etiologies, and complex exposures (e.g., the different constituents of sidestream and mainstream smoke) are untenable. '), HighwireSpan(start=4765, length=539, text='\r\n\r\nBut how do we know that the factory workers were not dying or suffering other ill effects? Snow cited no studies. All too often the absence of data is argued as proof of no effect. This issue becomes especially difficult when regulatory decisions are being made. In the absence of evidence, can something be considered safe? While science is important, it is ultimately social forces, as much as science, that guide regulators in decision-making. '), HighwireSpan(start=5307, length=1484, text='\r\n\r\nSnow\'s statements and the questions that were put to him call to mind some of the fundamental difficulties inherent in environmental epidemiology. Today, there are numerous examples of residents who live near potential environmental hazards claiming health effects that can never be proven beyond a reasonable doubt. Although the "gold standard" is an unbiased risk estimate with precise confidence limits, studies focused on overt health effects are invariably underpowered because of the small numbers of residents in the neighborhoods of interest. Other creative approaches to assessment of subclinical health effects are more costly and difficult to implement, but even these studies are often too small for conclusive results. Yet, what is the right thing to do? If we wait for strong scientific evidence before we act\x97if we require proof that workers are dying or evidence of overt illness in the community\x97have we waited too long? Few clusters are ever resolved with the identification of a causal link between some localized exposure and disease. While many apparent clusters may be artifacts, what is the real cost of the true hazards that cannot be proven? These were the issues facing Parliament when Snow testified on behalf of industry. '), HighwireSpan(start=6794, length=604, text='\r\n\r\nWhat is the role of the epidemiologist in this quagmire? In Snow\'s London, the living conditions of people near the factories were likely to have been dismal. There were no doubt residents who perceived their symptoms as being related to the smells\x97smells that, if nothing else, impacted the quality of life. Policy-makers must balance "doing the right thing" with regard to human suffering and quality of life with the financial costs of doing so. Epidemiology can only go so far in providing the answers. '), HighwireSpan(start=7401, length=1174, text='\r\n\r\nIt is this political and social tug-of-war that makes environmental epidemiology especially difficult. On the one hand, there are well\x97funded industries with a financial stake in the outcome of such research. As Vandenbroucke notes (2), these industries often are in a position to exploit the many weaknesses that epidemiologists are trained to identify in their own studies and in the work of others to cast potentially damaging results in a more favorable light. On the other hand, there are environmental groups committed to proving that a particular environmental exposure can be linked to a variety of personal complaints; these groups may be motivated by the possibility of effecting social change through science or by the prospect of receiving needed medical attention or financial compensation. Those who attempt to work in this arena often find themselves and their research attacked from all directions. '), HighwireSpan(start=8578, length=1091, text='\r\n\r\nEnvironmental epidemiology is difficult to conduct today for other reasons as well. Adequate tools with which to measure and quantify exposures are lacking. Studies are often unable to detect meaningful effects because exposures are low, infrequent, or difficult to measure with certainty. How many investigators are willing to tackle this problem? In the case of the bone-boiling factories, would research linking questionnaire data on symptoms to factory releases be believed? Would a study relating distance from the factory to disease be sufficient evidence of effect? What health effects would be plausible based on known biologic mechanisms? How well could those effects be measured, and could they be measured objectively? Is there a biomarker of exposure? If a biomarker exists, does it measure relevant past exposures? Is the measure unaffected by current health status\x97particularly the disease under study? '), HighwireSpan(start=9672, length=385, text="\r\n\r\nIn addition to Lilienfeld's historical report and Vandenbroucke's commentary, this issue of the Journal features papers that illustrate various aspects of the difficulties faced in studying health effects of environmental exposures. Several of these include innovative attempts to improve the quality of such research. "), HighwireSpan(start=10060, length=1974, text="\r\n\r\nThe paper by Viel et al. (5) may come closest to what many may think of as environmental epidemiology. The authors have examined the spatial distribution of soft tissue sarcomas and non-Hodgkin's lymphomas around an incinerator with high dioxin emissions. Their results are suggestive but need to be followed by studies incorporating more rigorous exposure assessment\x97perhaps a biologic measure of exposure such as that used in the study of polychlorinated biphenyls and breast cancer reported by Zheng et al. (6). Other studies described in this issue used a variety of approaches to exposure assessment. Rondeau et al. (7) linked estimates of levels of aluminum and silica in drinking water to risks of dementia and Alzheimer's disease. Laden et al. (8) used questionnaire data on use of electric blankets to estimate exposure to electromagnetic fields, and Gustavsson et al. (9) used questionnaire data and expert assessment by industrial hygienists to classify environmental and occupational exposures. Radiation workers are one of the few groups for which historical records of personal exposure typically are available. Dupree-Ellis et al. (10) took advantage of such records to estimate cumulative external radiation exposure. "), HighwireSpan(start=12037, length=2544, text='\r\n\r\nSeveral of the papers evaluate methods for assessing exposure. For example, Oglesby et al. (11) average individual-level annoyance scores to estimate community-level exposure to air pollution. The authors propose that this measure better accounts for exposure variability than data from fixed-site monitoring stations. This is an interesting twist in a field where much work is based on linking data from monitoring stations with population-level mortality statistics. The measure seems to be easy to operationalize, and it correlates well with monitoring station data, although its ultimate utility may be limited. The real gold standard\x97a more precise direct measure of individual exposure, rather than another indirect measure\x97is what is needed. Hwang et al. (12) propose an alternative modeling approach whereby air pollution monitoring station data are used to ascribe exposures to individuals with and without school absences due to respiratory disease. Auvinen et al. (13) compare several possible methods for measuring and classifying exposure to electromagnetic fields. This is a topic that has been hurt by the lack of consensus on the best and most appropriate exposure measure, and results tend to vary for studies employing different exposure metrics. The paper by Karagas et al. (14) attempts to link a biologic measure, arsenic in toenails, with an environmental measure of arsenic in water. The toenail measure is likely to reflect total body burden, but it appears to correlate with water only when water levels are high. This presents an interesting regulatory dilemma. The best epidemiologic research may be based on a direct measure of body burden such as levels in toenails, whereas it is water levels that need to be regulated. Studies of toenail arsenic levels may not shed direct light on the link between water levels and disease. '), HighwireSpan(start=14584, length=523, text='\r\n\r\nAs these papers demonstrate, technological advances are making possible a wide range of new study designs and strategies to better assess both exposures and outcomes. Although progress has been made, research in environmental epidemiology is far from perfect. As epidemiologists face pressures and criticisms from industry, regulatory bodies, and other scientific disciplines, it is important to not lose sight of the lessons from John Snow. '), HighwireSpan(start=15110, length=51, text='\r\n\r\n\r\n\r\nNOTES'), HighwireSpan(start=15164, length=366, text='\r\n\r\n\r\nReprint requests to Dr. Dale P. Sandler at this address (e-mail: sander{at}niehs.nih.gov<!--\r\n var u = "sander", d = "niehs.nih.gov"; document.getElementById("em0").innerHTML = \'<a href="mailto:\' + u + \'@\' + d + \'">\' + u + \'@\' + d + \'<\\/a>\'//-->). '), HighwireSpan(start=15533, length=54, text='\r\n\r\n\r\nREFERENCES'), HighwireSpan(start=15590, length=5710, text="\r\n\r\n\r\n\r\n\r\n Lilienfeld DE. John Snow: the first hired gun? Am J Epidemiol 2000;152:4\x969.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Vandenbroucke JP. Invited commentary: the testimony of Dr. Snow. Am J Epidemiol 2000;152:10\x9612.[Free Full\xa0Text]\r\n\r\n\r\n Foreman CH Jr. The promise and peril of environmental justice. Washington, DC: Brookings Institute, 1998.\r\n\r\n\r\n Horton R. The new new public health of risk and radical engagement. (Editorial). Lancet 1998;352:251.[ISI][Medline]\r\n\r\n\r\n Viel J-F, Arveux P, Baverel J, et al. Soft-tissue sarcoma and non-Hodgkin's lymphoma clusters around a municipal solid waste incinerator with high dioxin emission levels. Am J Epidemiol 2000;152:13\x9619.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Zheng T, Holford TR, Tessari J, et al. Breast cancer risk associated with congeners of polychlorinated biphenyls. Am J Epidemiol 2000;152:50\x968.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Rondeau V, Commenges D, Jacqmin-Gadda H, et al. Relation between aluminum concentrations in drinking water and Alzheimer's disease: an 8-year follow-up study. Am J Epidemiol 2000;152:59\x9666.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Laden F, Neas LM, Tolbert PE, et al. Electric blanket use and breast cancer in the Nurses' Health Study. Am J Epidemiol 2000;152:41\x969.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Gustavsson P, Jakobsson R, Nyberg F, et al. Occupational exposure and lung cancer risk: a population-based case-referent study in Sweden. Am J Epidemiol 2000;152:32\x9640.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Dupree-Ellis E, Watkins J, Ingle JN, et al. External radiation exposure and mortality in a cohort of uranium processing workers. Am J Epidemiol 2000;152:91\x965.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Oglesby L, Künzli N, Monn C, et al. Validity of annoyance scores for estimation of long term air pollution exposure in epidemiologic studies: The Swiss Study on Air Pollution and Lung Diseases in Adults (SAPALDIA). Am J Epidemiol 2000;152:75\x9683.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Hwang J-S, Chen Y-J, Wang J-D, et al. Subject-domain approach to the study of air pollution effects on schoolchildren's illness absence. Am J Epidemiol 2000;152:67\x9674.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Auvinen A, Linet MS, Hatch EE, et al. Extremely low-frequency magnetic fields and childhood acute lymphoblastic leukemia: an exploratory analysis of alternative exposure metrics. Am J Epidemiol 2000;152:20\x9631.[Abstract/Free Full\xa0Text]\r\n\r\n\r\n Karagas MR, Tosteson TD, Blum J, et al. Measurement of low levels of arsenic exposure: a comparison of water and toenail concentrations. Am J Epidemiol 2000;152:84\x9690.[Abstract/Free Full\xa0Text]\r\n\r\n\r\nReceived for publication March 17, 2000. \r\n\r\nAccepted for publication March 29, 2000."), HighwireSpan(start=21303, length=129, text='\r\n\r\n\t\t\r\n        \r\n        \r\n\t\r\n\t\r\n\t\r\n\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n \r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n'), HighwireSpan(start=21435, length=124, text='\r\nRelated articles in Am. J. Epidemiol.:\r\n'), HighwireSpan(start=21562, length=344, text='\r\n\r\n\t\r\n\tJohn Snow: The First Hired Gun?\r\n\tDavid E. Lilienfeld\r\n\t\r\nAm. J. Epidemiol. 2000 152: 4-9.\r\n\r\n\t\r\n\t\r\n\t[Abstract]\r\n\t\r\n\t[FREE Full Text]\r\n\t\r\n\t\xa0\r\n\t'), HighwireSpan(start=21909, length=362, text='\r\n\t\r\n\tInvited Commentary: The Testimony of Dr. Snow\r\n\tJan P. Vandenbroucke\r\n\t\r\nAm. J. Epidemiol. 2000 152: 10-12.\r\n\r\n\t\r\n\t\r\n\t[Extract]\r\n\t\r\n\t[FREE Full Text]\r\n\t\r\n\t\xa0\r\n\t'), HighwireSpan(start=22274, length=137, text='\r\n\t\r\n\r\n\r\n  \r\n  \r\n  \r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n'), HighwireSpan(start=22414, length=16, text='\r\n'))),
            9: HighwireDoc('10901331', 'ajepidem', "\r\nSubject-Domain Approach to the Study of Air Pollution Effects on Schoolchildren's Illness Absence\r\n", (HighwireSpan(start=0, length=423, text="\r\n\r\n\r\nSubject-Domain Approach to the Study of Air Pollution Effects on Schoolchildren's Illness Absence\r\n\r\n\r\n\r\nJing-Shiang Hwang1, \r\nYi-Ju Chen2, \r\nJung-Der Wang3,4, \r\nYu-Min Lai3, \r\nChun-Yuh Yang5 and \r\nChang-Chuan Chan3\r\n"), HighwireSpan(start=426, length=565, text='\r\n\r\n1 Institute of Statistical Science, Academia Sinica, Taipei, Taiwan.\r\n2 Institute of Epidemiology, College of Public Health, National Taiwan University, Taipei, Taiwan.\r\n3 Institute of Industrial Hygiene and Occupational Medicine, College of Public Health, National Taiwan University, Taipei, Taiwan.\r\n4 Department of Internal Medicine, National Taiwan University Hospital, Taipei, Taiwan.\r\n5 Department of Public Health, Kaohsiung Medical College, Kaohsiung, Taiwan.\r\n'), HighwireSpan(start=994, length=3118, text="\r\n\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nABSTRACT\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\n\r\nIn this paper, the authors propose a new statistical modeling technique, the subject-domain approach, which is theoretically proven to be equivalent to the time-domain approach in detecting an association between exposure and response with time trends. The authors use an empirical data set from a school absence monitoring study conducted during the 1994\x961995 school year in Taiwan to demonstrate this subject-domain approach's application to environmental epidemiologic studies. Because the subject-domain models can control the influential personal confounding factors in the models, they show greater statistical power than the traditional time-domain approaches in determining the relation between air pollution and illness absences. The authors' models found that the schoolchildren's risks of illness absence were significantly related to acute exposures to nitrogen dioxide and nitrogen oxides with a 1-day lag (p < 0.01) at levels below the World Health Organization's guidelines. By contrast, the authors could not detect significant associations between air pollution and schoolchildren's absenteeism using time-domain approaches. Such findings imply that the models built on subject domain may be a general solution to the problem of the ecologic fallacy, which is commonly encountered in environmental and social epidemiologic studies. "), HighwireSpan(start=4115, length=8, text='\r\n\r\n\r\n\r\n'), HighwireSpan(start=4126, length=106, text=' air pollution; epidemiologic methods; nitrogen dioxide; statistics; time-dependent covariate; time series'), HighwireSpan(start=4235, length=28, text='\r\n\t\r\n\t\r\n                \r\n\t\t'), HighwireSpan(start=4266, length=151, text='Abbreviations: \r\n\t\r\nPM10, particulate matter with a diameter less than 10 µm; SOAP&HIT, Study On Air Pollution and Health In Taiwan'), HighwireSpan(start=4420, length=5037, text="\r\n\r\n\r\n \r\n \xa0\xa0\r\nINTRODUCTION\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\nSeveral epidemiologic studies have used time-domain methods to illustrate the effects of air pollution on hospital admissions and emergency room visits for various respiratory diseases (1\x9610). In these ecologic-type epidemiologic studies, daily counts of hospital admissions or emergency room visits in a geographic area are usually regressed against pollution levels measured at several fixed-site air monitoring stations in the same areas. In applications of the same time-domain methods to investigation of the relation between air pollution and illness absence, neither community-based studies nor cohort-based studies show consistent findings of air pollution effects on absence (11\x9616). These studies' inherent problem of the ecologic fallacy, i.e., the lack of subject-specific information in the study population, tends to bias study results toward the null. Traditional models built on time domain usually cannot include subject-specific attributes in the models, even when such personal information is available. In the case of studies using illness absence as the outcome, we must control for each subject's personal factors, such as the individual's susceptibility factors and general environmental conditions, in order to illustrate air pollution effects on the risk of illness absence. One solution to this problem is to transform original time-series data into a subject-domain problem and make within-subject comparisons. An example is the case-crossover design for analysis of data with time trends (17, 18). Such a subject-domain approach can better estimate relative risks, because individual susceptibility factors are controlled by within-subject comparisons. "), HighwireSpan(start=9460, length=1627, text="\r\n\r\nIn this paper, we show that it is also valid to use the subject-domain approach to analyze time-domain problems and make between-subject comparisons. We demonstrate that time-series data can be equivalently analyzed by time-domain and subject-domain modeling approaches, theoretically as well as empirically. We further demonstrate, using data from an empirical study, that the subject-domain model is better than the time-domain model for uncovering true effects of air pollution on illness absence because person-related information can be included in the model. The data set used is from a school absence monitoring study we conducted during the 1994\x961995 school year in Taiwan. The study examined 4,679 schoolchildren's illness absences attributed to respiratory diseases at six schools. It was part of an epidemiologic study on air pollution and health, the Study On Air Pollution and Health In Taiwan (SOAP&HIT) (19). In the SOAP&HIT, air quality data were measured from fixed-site ambient air monitoring stations, and information on personal and housing characteristics was obtained from a questionnaire survey. Here we describe a subject-domain approach to the estimation of acute effects of exposure to nitrogen dioxide and nitrogen oxides on the risk of illness absence from school. "), HighwireSpan(start=11090, length=2359, text='\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nMATERIALS AND METHODS\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\nStudy population\r\n\r\nWe collected the attendance records of 5,072 students aged 6\x9612 years from six primary schools in Taiwan during 1994\x961995. The study population included 705 students from Taihsi, 954 from Keelong, 1,386 from Sanchung, 796 from Toufen, 701 from Jenwu, and 530 from Linyuan. The Taihsi school is in a rural area; the Keelong and Sanchung schools are in urban areas; and the Jenwu, Linyuan, and Toufen schools are in industrial areas where petrochemicals are produced. From these 5,072 schoolchildren, we used 4,697 students (92 percent) with absence records covering at least one school year and complete information from the questionnaire survey as our study cohort. '), HighwireSpan(start=13452, length=553, text='\r\n\r\nIllness absence\r\n\r\nTeachers in each class of these six schools helped document the records and causes of absence for each absentee. The causes of illness absence were first screened by school nurses daily and doubly checked by trained physicians biweekly. We included only absenteeism due to respiratory diseases in our data analysis. If an individual had consecutive days of absence, only the first day was considered for that event in the analyses. '), HighwireSpan(start=14008, length=1418, text="\r\n\r\nEnvironmental data\r\n\r\nThe hourly concentrations of six major air pollutants--particulate matter with a diameter less than 10 µm (PM10), sulfur dioxide, nitrogen oxides, nitrogen monoxide, nitrogen dioxide, and ozone\x97were continuously measured by air-monitoring stations located in these six primary schools. Weather data, including temperature, wind speed and direction, and precipitation, were also measured continuously in these air-monitoring stations. The environmental data obtained from school-based monitoring stations, which are located in community centers, are generally well representative of a community's ambient air quality in Taiwan (20). Since Taiwanese schoolchildren spend most of their outdoor time at school, where classrooms are always well ventilated naturally and without air conditioning, we calculated daytime averages of environmental data from 8:00 a.m. to 6:00 p.m. in order to represent their outdoor exposures. A questionnaire survey on home characteristics (described below) was used to account for children's potential exposures to air pollutants indoors. "), HighwireSpan(start=15429, length=1100, text="\r\n\r\nQuestionnaire\r\n\r\nWe treated subjects' personal information from the questionnaire survey as confounding factors to be controlled in our subject-domain model. The survey was carried out at the beginning of the study. The information gathered in the questionnaire included an individual student's demographic data, personal and family history of respiratory diseases, and characteristics of the home environment. Major categories of respiratory symptoms and diseases in the questionnaire included morning cough, day or night cough, chronic cough, shortness of breath, nasal symptoms, sinusitis, wheezing or asthma, allergic rhinitis, bronchitis, pneumonia, and family history of respiratory diseases. Key indicators of home environment included a crowding index, household smoking, the presence of pets or fowl, coal stove use, gas-cooker use, incense-burning, mosquito repellent-burning, indoor plants, and home dampness. "), HighwireSpan(start=16532, length=2450, text="\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nSTATISTICAL METHODS\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\nDaily health events can generally be represented by yit for students in a school. Here, i = 1,... I index the schoolchil-dren and t = 1,... T index the school days. Let yit be equal to 1 when subject i is absent on day t and zero otherwise. Let xt be the area level of a pollutant measured from representative monitoring stations on lagged h days. The lag ranging from 0 to 4 days was used in this paper. We may assume that yit is a realization from a Bernoulli distribution with a rare rate of pit, which may be affected by at least two main effects of subject i's personal characteristics and the associated environmental conditions xt. "), HighwireSpan(start=18985, length=1217, text='\r\n\r\nTime-domain approach\r\n\r\nSince illness absence is usually a rare event, it is difficult to select a proper model for testing the association between xt and original observed sparse yit directly. However, if xt has an acute effect on yit, with the assumption of independent subjects, xt should also have an acute effect on daily total counts of absence, . Hence, the conventional time-domain approaches treat the aggregated absence counts by times, y+t, as a conditionally independent Poisson variable when the mean total number of absentees, , is not too small. It is easily and widely applied to health effects studies but usually requires a large population size to have a chance to detect a significant association between xt and y+t from fitted Poisson or negative binomial models. '), HighwireSpan(start=20205, length=1651, text="\r\n\r\nSubject-domain approach\r\n\r\nOne equivalent method of aggregating data by time is to aggregate the sparse yit data by subject. Similarly, if xt have affected subject i such that yit = 1 for some t's in the study period, the average of these xt's can be treated as having an acute effect on the subject's total absence in the study time period, . For each subject having yi+, we define the average of these xt's as the subject's level of exposure, denoted by . When subjects have no absences during the study period, their air pollution levels are given a constant value, that is, the average of xt for all t with y+t = 0. Conceivably, the original association between the area exposure index, xt, and the time-specific population absence frequency in an area, y+t, in the time-domain approach will be equivalent to the association between individual exposure levels, zi, and each subject's absence frequency observed over the entire study period, yi+, in the subject-domain approach. The theoretical proof of such equivalence is given in the Appendix. "), HighwireSpan(start=21859, length=991, text="\r\n\r\nUnder this framework, we can reasonably assume yi+ to approximate a Poisson distribution with a mean obtained by . Obviously, yi+ is affected not only by the subject's air pollution levels zi and weather levels wi but also by personal/housing characteristics and other confounding factors. Here, the individual level of weather exposures for the ith schoolchild, w>i, is calculated by replacing the pollutant level of xt in the zi statistic by weather measurements. Therefore, having adjusted for the influential personal variables, we expect that models built on subject domain are more powerful in detecting the association between pollutants and health outcomes. "), HighwireSpan(start=22853, length=199, text="\r\n\r\nCombining data from all students in the six schools, we propose using standard Poisson regression to model subjects' absence counts as follows:\r\n "), HighwireSpan(start=23055, length=810, text='\r\n\r\nwhere pki+ is the expected total number of absences for subject i at school k and Tk is the number of school days in the study period on which data were collected at the kth school. The individual level of air pollution and weather exposures for schoolchild i at school k are denoted by vectors zki and wki. The vector uki consists of explanatory variables including a dummy variable for area characteristics and covariates for personal characteristics. '), HighwireSpan(start=23868, length=1828, text='\r\n\r\nSelection of questionnaire items\r\n\r\nTo reduce the burden of selecting proper personal variables from a large number of questionnaire items, we used classical association-testing approaches of Pearson\'s 2 test and the generalized logit model to identify a few key factors (21, 22). We classified the response variable of absence counts into three categories of none (0 absences), low (1\x963 absences), and high (>4 absences), which had a natural ordering. In the same way, we classified each personal variable into appropriate categories. For example, we classified "school grade" into three categories of low (grade 1\x962), medium (grade 3\x964), and high (grade 5\x966) and the symptom "day or night cough" into two categories of yes and no. We first applied Pearson\'s 2 test to exclude any items that were not significantly associated with absence incidence. We then entered the items that had been screened significant into the generalized logit models to finalize the selection of personal variables. We used generalized logit models as the second step of variable selection, because the responses had a natural ordering. We reserved items that were statistically significant in more than two schools as the personal variables for the subject-domain Poisson regression model. '), HighwireSpan(start=25699, length=2804, text="\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nRESULTS\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\nIndividual level of exposure\r\n\r\nAlthough the data were analyzed with different time lags, we present only the results for a 1-day lag for illustration and simplicity. As described above, individual levels of air pollution exposure were calculated according to individual students' absence records from fixed-site ambient monitoring data. For example, suppose one student has records of five absences on the dates May 1, May 2, June 4, September 27, and October 3 during the study period. Accordingly, daytime average pollutant levels measured on April 30, June 3, September 26, and October 2 are averaged to represent this student's 1-day-lagged individual level of air pollution exposure. Exposure levels for students without any absences during the school year are calculated by averaging ambient air monitoring data on days with no absences during the study period. In total, we derive individual air pollution levels, zi, of six air pollutants and two meteorologic parameters, wi, for 4,697 students with a 1-day lag from the SOAP&HIT data set. "), HighwireSpan(start=28506, length=1506, text="\r\n\r\nThe 1-day-lagged individual air pollution levels classified by absence counts are shown in table 1. Among 4,697 students, 17.5 percent had at least one absence and 82.5 percent had no absences. For the 3,875 students without absences, the individual air pollution levels were 17.2 parts per billion (ppb) for sulfur dioxide, 39.3 ppb for nitrogen oxides, 25.7 ppb for nitrogen dioxide, 74.3 µg/m3 for PM10, and 45.9 ppb for ozone. For the 822 students with at least one absence, the individual air pollution levels were 17.8\x9619.9 ppb for sulfur dioxide, 41.2\x9647.1 ppb for nitrogen oxides, 27.5\x9631.8 ppb for nitrogen dioxide, 80.2\x9680.4 µg/m3 for PM10, and 46.1\x9646.2 ppb for ozone. Apparently, absentees' levels of pollution exposure were all greater than nonabsentees' pollution levels. Individual levels of sulfur dioxide, nitrogen oxides, and nitrogen dioxide were also positively correlated with absence frequency. Such results indicate that these three pollutants may have acute effects on illness absence. By contrast, PM10, ozone, and rainfall may have no acute effects on absence, because their individual levels did not show trends with different degrees of absence. "), HighwireSpan(start=30015, length=795, text='\r\n\r\n\r\n\r\n\r\nView this table:\r\n[in this window]\r\n[in a new window]\xa0\r\n\r\nTABLE 1. One-day-lagged individual exposures to air pollutants among 4,697 schoolchildren, by number of absences during the 1994\x961995 school year, Taiwan'), HighwireSpan(start=30813, length=1939, text="\r\n\r\n\r\n\r\n\xa0\r\n\r\n\r\nModel comparisons\r\n\r\nTo illustrate the improvement in statistical power for detecting pollutant effects on the risk of school absence, we make model comparisons among Poisson models built on time domain and subject domain, without and with adjustment for personal factors. All of these three models are also adjusted for weather exposures. The effects of six air pollutants on the risks of illness absence estimated by these three different modeling approaches are summarized in table 2. The equivalence of time-domain and subject-domain modeling is affirmed from the estimated relative risks and 95 percent confidence intervals. These two models cannot detect any significant air pollution effects on absence. By contrast, the subject-domain models with adjustment for personal factors (SP) illustrate significant effects on schoolchildren's illness absence by two air pollutants, nitrogen oxides and nitrogen dioxide. The SP models predict that relative risks of illness absence are 1.11 and 1.23 for every 10-ppb increase in acute exposure to nitrogen oxides and nitrogen dioxide, respectively. The SP models also find that relative risks are increased with narrower confidence intervals for the other four air pollutants, although their values are not statistically significant. Such empirical results demonstrate that controlling for personal factors in the SP models contributes significant gains to the models. Detailed effects of personal factors on illness absence are described below. "), HighwireSpan(start=32755, length=817, text="\r\n\r\n\r\n\r\n\r\nView this table:\r\n[in this window]\r\n[in a new window]\xa0\r\n\r\nTABLE 2. Effects of air pollutants on schoolchildren's illness absences, as estimated by a 10-unit increase in pollution levels with a 1-day lag, Taiwan, 1994\x961995*"), HighwireSpan(start=33575, length=1545, text="\r\n\r\n\r\n\r\n\xa0\r\n\r\n\r\nKey subject attributes included in the subject-domain model\r\n\r\nResults from the generalized logit model suggested that school grade was a common factor affecting individual students' absence records at all six schools. Children in low grades had higher absence rates than those in high grades. The presence of family or personal respiratory symptoms/diseases was also an important factor affecting individual students' absence records at all six schools. Having a family history of respiratory diseases increased schoolchildren's absence rates in Taihsi, Keelong, and Jenwu. Illness absence also increased in Keelong, Sanchung, Linyuan, and Toufen when schoolchildren had the respiratory symptom of nasal symptoms, shortness of breath, or cough or the respiratory disease of pneumonia or asthma. By contrast, no single housing factor significantly affected students' absence rates in more than two schools. Accordingly, school grade, the child respiratory symptom of day or night cough, the child respiratory disease of wheezing or asthma, the child respiratory disease of pneumonia, and family history of respiratory diseases were five key individual confounding factors which were controlled in our subject-domain model (SP). "), HighwireSpan(start=35123, length=680, text="\r\n\r\nEffects of various factors on illness absence\r\n\r\nThe expected effects of air pollution and other predictors on illness absence, as estimated by the subject-domain model with a 1-day lag, are presented in table 3. Acute exposures to nitrogen oxides and nitrogen dioxide had significant effects on individual students' total absence counts (p < 0.01), and acute exposures to sulfur dioxide had marginal effects (p = 0.08). By contrast, acute exposures to either PM10 or ozone had no significant effects on illness absence. "), HighwireSpan(start=35806, length=813, text="\r\n\r\n\r\n\r\n\r\nView this table:\r\n[in this window]\r\n[in a new window]\xa0\r\n\r\nTABLE 3. Effects of air pollution on schoolchildren's illness absences (relative risk), as estimated by subject-domain models including personal factors, Taiwan, 1994\x961995"), HighwireSpan(start=36622, length=1780, text="\r\n\r\n\r\n\r\n\xa0\r\n\r\n\r\nIn addition to air pollution effects on absence, the subject-domain model also detected other factors associated with schoolchildren's illness absence: temperature, community, grade, the personal symptom of day or night cough, and family history of respiratory diseases. Illness absence increased as the ambient temperature decreased. Apparently, there was also a community effect on absence after the air pollution effects of nitrogen dioxide and nitrogen oxides, weather, and other factors were adjusted for in the subject-domain model. Since the data had been adjusted for relatively worse weather conditions, the relative risks of absence for the two northern urban schools in Keelong and Sanchung were slightly lower than those for the rural Taihsi school. Compared with the rural school in Taihsi, illness absences were significantly higher in the schools in Jenwu and Linyuan but significantly lower in the school in Toufen. As table 4 shows, mean daily absence rates were 1.0 percent per thousand in Taihsi, 1.5 percent per thousand in Jenwu, and 1.9 percent per thousand in Linyuan. Overall, schoolchildren in the Linyuan and Jenwu southern petrochemical areas took 1.5\x961.9 times more sick leave than children in the rural Taihsi area. Differences in general environmental conditions, nutritional situations, and social and cultural status among communities are some possible explanations for the community effect on absence. "), HighwireSpan(start=38405, length=783, text='\r\n\r\n\r\n\r\n\r\nView this table:\r\n[in this window]\r\n[in a new window]\xa0\r\n\r\nTABLE 4. Median daily air pollution and weather levels and mean daily absence rates of six schools in Taiwan during the 1994\x961995 school year'), HighwireSpan(start=39191, length=1764, text="\r\n\r\n\r\n\r\n\xa0\r\n\r\n\r\nAs table 4 shows, the yearlong measurements of ambient air quality indicate that air pollution is significantly worse in Linyuan and Jenwu than in Taihsi, while weather conditions are better in Linyuan and Jenwu. Among six air pollutants, the levels of PM10 and ozone in the schools of Jenwu and Linyuan are above current air quality guidelines. Although the concentrations of nitrogen oxides and nitrogen dioxide are still below the air quality guidelines, the air pollution levels are relatively higher in Jenwu, Linyuan, and Toufen in comparison with Taihsi. Relatively higher sulfur dioxide concentrations are also found in the three schools in Linyuan, Jenwu, and Toufen in comparison with the school in Taihsi. Therefore, schoolchildren's chronic exposure to relatively higher air pollution levels may result in higher rates of illness absence in Linyuan and Jenwu. However, the community effects on the low absence rate in Toufen, 0.6 percent per thousand, may be attributable to the residents' ethnicity rather than environmental conditions in Toufen. Although Toufen is located in a petrochemical area, its air pollution level is moderate in comparison with Linyuan and Jenwu. By contrast, the Toufen school is in a township populated mostly by persons of Hakka ethnicity, and schoolchildren in Toufen may take fewer sick days than expected because of the Hakka's renowned diligence in attending school. "), HighwireSpan(start=40958, length=2833, text="\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nDISCUSSION\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\nThe subject-domain approach proposed in this paper has the advantage of including subject-related information in the model, which can largely reduce the confounding effects seen in the traditional time-domain model. Therefore, the subject-domain model can significantly increase statistical power for detecting associations between exposures and effects in environmental epidemiologic studies. To illustrate the equivalence of statistical analysis between time-domain and subject-domain approaches with the same environmental data, we used only pollutant, weather, and area characteristic factors in the time-domain model in this paper. The residuals from the fitted time-domain models showed no patterns of day-of-week or other long term trends, except for minor autocorrelation in our data. Our subject-domain approach ignored the time-dependent structure within each subject's absence records. We believe that it has little effect on the inference, because a subject's autocorrelated absence records are usually a reflection of personal factors, which are treated as potential confounders and were included in our models. "), HighwireSpan(start=43794, length=1355, text="\r\n\r\nFor most air pollution and mortality studies, we usually find substantial seasonal fluctuations and long term trends in mortality data that cannot be fully explained by either air pollution or meteorology. Such trends and seasonality can be modeled by the nonparametric function fitting method in the time-domain framework. For a study on air pollution and hospital admission, we can also easily solve the day-of-week problem by simply adding terms for dummy variables in the time-domain approach. Therefore, our subject-domain model may suffer a loss of some statistical power in such applications because of its lack of control for seasonality and day-of-week patterns. However, the limitations might be removed by building time-dependent exposure patterns in the subject-domain models. For example, we can redefine a subject's exposure level by using the observed time pattern to weight the environmental data before weighting across the subject's absence records. Another possible solution would be to identify significant trends and patterns in health outcome series first, and remove them before constructing the subject-domain models. "), HighwireSpan(start=45152, length=918, text='\r\n\r\nApparently, using the subject-domain approach to analyze the time x subject matrix of our data set not only detects the associations between response (illness absence) and predictors (air pollution) but also identifies several personal factors influencing illness, which the time-series approach is unable to recognize. Such findings imply that the subject-domain model may be a general solution to the problem of the ecologic fallacy, which is commonly encountered in environmental and social epidemiologic studies. One immediate application of this finding would be to use the subject-domain approach to reanalyze data from previous studies on air pollution and health, especially when informative personal data are available in the databases. '), HighwireSpan(start=46073, length=830, text="\r\n\r\nAlthough Navidi's (18) bidirectional case-crossover design is also a subject-domain approach, he considers only cases in the logistic model. By contrast, our subject-domain approach used all subjects, i.e., cases and noncases, in the Poisson model. With less than 17 percent of our study population ever absent, we expect that the statistical gain from our approach is more significant than that from the crossover design, through the inclusion of all noncases' information in our study. Furthermore, the computations in our standard Poisson models are much more straightforward than the estimation procedures in Navidi's models. "), HighwireSpan(start=46906, length=849, text="\r\n\r\nWe argue that the subject-domain model has no greater limitation than the conventional time-series approach in the interpretation of associations between air pollution and absenteeism. In the time-domain approach, we use air pollution levels measured at specific fixed monitoring sites as acute exposure proxies for all schoolchildren on a particular day. In the subject-domain model, we use the average of absence-related air pollution levels measured at fixed monitoring sites to represent an individual's acute exposures. In fact, personal exposures to air pollutants are not actually measured directly for individual schoolchildren in either our subject-domain model or the conventional time-domain approach. "), HighwireSpan(start=47758, length=1213, text='\r\n\r\nWe detected the same air pollution effects of nitrogen dioxide and nitrogen oxides on illness absence in the SOAP&HIT data set when we used daytime as well as daily average concentrations with 0- to 4-day lags as levels of exposure. Such findings are consistent with the results of other epidemiologic studies, which also report significant associations between nitrogen oxide-linked pollution and health effects at levels below World Health Organization guidelines, which are 80 ppb for 24-hour average levels and 150 ppb for 1-hour average levels (23\x9626). Accordingly, we recommend that more studies be conducted to investigate the biologic plausibility of an effect of nitrogen oxide tox-icity on the respiratory system. '), HighwireSpan(start=48974, length=3459, text="\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nAPPENDIX\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\nProof of Equivalence between the Time-Domain and Subject-Domain Approaches\r\n\r\nFollowing the notation defined in the text, the daily illness absence counts can also be decomposed as , for some m far less than I. Here, nt(j) is the number of subjects who are absent on day t and have a total count of illness absences j in a school during the study period. Empirically, we have  for 2  j  m. The set of whole population indices can be decomposed into a union of disjoint subsets, B(j), 0  j  m, which consists of subject indices whose total counts of illness absence are exactly j in the study period. The subject's expected mean individual air pollution levels, whose total absence count is j, could be estimated by the average  for j > 0. For those with no absences, i.e., j = 0, the expected mean individual air pollution level is estimated by , where k is the number of days having y+t = 0. Therefore, a positive association of xt and y+t implies Z(j) > Z(j - 1) for j  1 and vice versa. "), HighwireSpan(start=52436, length=1283, text='\r\n\r\nIn fact, Z(j) can be further rewritten as , a weighted average of xt for j  1. Note that Z(0) is an equally weighted average of these xt with y+t = 0. If we let nt(0) = #B(0) when y+t = 0 and nt(0) = 0 when y+t > 0, we can rewrite Z(0) in the same form, . Therefore, we will show that Z(j) > Z(j - 1) for j  1 when xt and y+t are positively associated and vice versa. That is, we need to show that the weights  when xt is large and  when xt is relatively small. '), HighwireSpan(start=53722, length=627, text='\r\n\r\nIn the simple case of j = 1, we have either  > 0 and nt(0) = 0 for large xt or nt(1) = 0 and  =  for smaller xt values; the truth of the equivalence statement is therefore obvious. For the case of j  2, we give detailed arguments below. '), HighwireSpan(start=54352, length=1342, text='\r\n\r\nIn practical application, nt(j - 1) tends to be greater than nt(j). Meanwhile, when xt is large and so is the associated y+t, with the assumption of a positive association, then both nt(j - 1) and nt(j) will be greater than zero. We may add one more assumption that there is a q(j) between 0 and 1, such that nt(j) is approximately equal to q(j)nt(j - 1). Let C1 be the set of time indices having both nt(j - 1) and nt(j) greater than zero. Those time indices with nt(j - 1) > 0 and nt(j) = 0 are grouped to C2. This may happen when y+t is not large enough, i.e., when a relatively small xt is observed. Hence, we complete the argument with the following two statements.\r\n '), HighwireSpan(start=55697, length=183, text='\r\n\r\nand\r\n '), HighwireSpan(start=55883, length=160, text='\r\n '), HighwireSpan(start=56046, length=680, text='\r\n\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nACKNOWLEDGMENTS\r\n\r\n\xa0\r\n\r\nThe research described in this article was conducted through the sponsorship of contracts awarded by the National Research Council, the Executive Yuan, Taiwan (NSC-84-2621-p-002-018, NSC-84-2621-p-002-024, NSC-85-2621-p-002-008, and NSC-85-2621-p-002-024). '), HighwireSpan(start=56729, length=155, text='\r\n\r\nThe authors acknowledge the technical support of the Taiwan Environmental Protection Agency in the measurement of air pollution. '), HighwireSpan(start=56887, length=843, text='\r\n\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nNOTES\r\n\r\n\xa0\r\n\r\n\r\nReprint requests to Dr. Chang-Chuan Chan, College of Public Health, National Taiwan University, Room 1447, No. 1, 1st sec., Jen-ai Road, Taipei, Taiwan (e-mail: ccchan{at}ha.mc.ntu.edu.tw<!--\r\n var u = "ccchan", d = "ha.mc.ntu.edu.tw"; document.getElementById("em0").innerHTML = \'<a href="mailto:\' + u + \'@\' + d + \'">\' + u + \'@\' + d + \'<\\/a>\'//-->). '), HighwireSpan(start=57733, length=11230, text='\r\n\r\n\r\n\r\n\r\n \r\n \xa0\xa0\r\nREFERENCES\r\n\r\n\r\nTOP\r\nABSTRACT\r\nINTRODUCTION\r\nMATERIALS AND METHODS\r\nSTATISTICAL METHODS\r\nRESULTS\r\nDISCUSSION\r\nAPPENDIX\r\nREFERENCES\r\n\r\n\xa0\r\n\r\n\r\n\r\n\r\n Walters S, Phupinyokul M, Ayres J. Hospital admission rates for asthma and respiratory disease in the West Midlands: their relationship to air pollution levels. Thorax 1995;50:948\x9654.[Abstract]\r\n\r\n\r\n Ponka A. Asthma and low level air pollution in Helsinki. Arch Environ Health 1991;46:262\x9670.[ISI][Medline]\r\n\r\n\r\n Ponka A, Virtanen M. Asthma and ambient air pollution in Helsinki. J Epidemiol Community Health 1996;50(suppl 1):S59\x9662.\r\n\r\n\r\n Castellsague J, Sunyer J, Saez M, et al. Short-term association between air pollution and emergency room visits for asthma in Barcelona. Thorax 1995;50:1051\x966.[Abstract]\r\n\r\n\r\n Anderson HR, Limb ES, Bland JM, et al. Health effects of an air pollution episode in London, December 1991. Thorax 1995;50:1188\x9693.[Abstract]\r\n\r\n\r\n Schwartz J, Slater D, Larson TV, et al. Particulate air pollution and hospital emergency room visits for asthma in Seattle. Am Rev Respir Dis 1993;147:826\x9631.[ISI][Medline]\r\n\r\n\r\n Bates DV, Baker-Anderson M, Sizto R. Asthma attack periodicity: a study of hospital emergency visits in Vancouver. Environ Res 1990;51:51\x9670.[ISI][Medline]\r\n\r\n\r\n Bates DV, Sizto R. Air pollution and hospital admissions in Southern Ontario: the acid summer haze effect. Environ Res 1987;43:317\x9631.[ISI][Medline]\r\n\r\n\r\n Thurston G, Ito K, Hayes CG, et al. Respiratory hospital admissions and summertime haze air pollution in Toronto, Ontario: consideration of the role of acid aerosols. Environ Res 1994;65:271\x9690.[ISI][Medline]\r\n\r\n\r\n Sunyer J, Anto JM, Murillo C, et al. Effects of urban air pollution on emergency room admissions for chronic obstructive pulmonary disease. Am J Epidemiol 1991;134:277\x9686.[Abstract]\r\n\r\n\r\n Romieu I, Lugo MC, Velasco SR, et al. Air pollution and school absenteeism among children in Mexico City. Am J Epidemiol 1992;136:1524\x9631.[Abstract]\r\n\r\n\r\n Moll Van Charante AW, Mulder PG. Effects of smog on absenteeism in forestry workers. Arch Environ Health 1996;51:34\x9641.[ISI][Medline]\r\n\r\n\r\n Ferris BG. Effect of air pollution on school absences and differences in lung function in first and second graders in Berlin, New Hampshire, January 1966 to June 1967. Am Rev Respir Dis 1970;102:591\x96606.[ISI][Medline]\r\n\r\n\r\n Verma MP, Schilling FJ, Becker WH. Epidemiological study of illness absences in relation to air pollution. Arch Environ Health 1969;18:536\x9643.[ISI][Medline]\r\n\r\n\r\n Wayne WS, Wehrle PF. Oxidant air pollution and school absenteeism. Arch Environ Health 1969;19:315\x9622.[ISI][Medline]\r\n\r\n\r\n Ponka A. Absenteeism and respiratory disease among children and adults in Helsinki in relation to low-level air pollution and temperature. Environ Res 1990;52:34\x9646.[ISI][Medline]\r\n\r\n\r\n Maclure M. The case-crossover design: a method for studying transient effects on the risk of acute events. Am J Epidemiol 1991;133:144\x9653.[Abstract]\r\n\r\n\r\n Navidi W. Bidirectional case-crossover designs for exposures with time trends. Biometrics 1998;54:596\x96605.[ISI][Medline]\r\n\r\n\r\n Chen PC, Lai YM, Wang JD, et al. Adverse effect of air pollution on respiratory health of primary school children in Taiwan. Environ Health Perspect 1998;106:331\x965.[ISI][Medline]\r\n\r\n\r\n Chan CC, Hwang JS. Site representativeness of urban air monitoring stations. J Air Waste Manag Assoc 1996;46:755\x9660.[ISI]\r\n\r\n\r\n Agresti A. An introduction to categorical data analysis. New York, NY: John Wiley and Sons, Inc, 1996.\r\n\r\n\r\n Agresti A. Categorical data analysis. New York, NY: John Wiley and Sons, Inc, 1994.\r\n\r\n\r\n Schwartz J, Zeger S. Passive smoking, air pollution, and acute respiratory symptoms in a diary study of student nurses. Am Rev Respir Dis 1990;141:62\x967.[ISI][Medline]\r\n\r\n\r\n Lebowitz MD, Collins L, Holberg CJ. Time series analyses of respiratory responses to indoor and outdoor environmental phenomena. Environ Res 1987;43:332\x9641.[ISI][Medline]\r\n\r\n\r\n Rutishauser M, Ackermann U, Braun C, et al. Significant association between outdoor NO2 and respiratory symptoms in preschool children. Lung 1990;168(suppl):347\x9652.[ISI][Medline]\r\n\r\n\r\n Braun-Fahrlander C, Ackermann-Liebrich U, Schwartz J, et al. Air pollution and respiratory symptoms in preschool children. Am Rev Respir Dis 1992;145:42\x967.[ISI][Medline]\r\n\r\n\r\nReceived for publication December 28, 1998. \r\n\r\nAccepted for publication November 29, 1999.'), HighwireSpan(start=68966, length=208, text='\r\n\r\n\t\t\r\n        \r\n        \r\n\t\r\n\t\r\n\t\r\n\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n \r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n  \r\n  \r\n  \r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n'), HighwireSpan(start=69177, length=16, text='\r\n'))),
            162258: HighwireDoc('16280387', 'toxsci', '\r\nCORRECTION\r\n', (HighwireSpan(start=0, length=148, text='\r\n\r\n\r\nCORRECTION\r\n\r\n\r\n\r\nJames F. Dillman, III and \r\nChristopher S. Phillips\r\n'), HighwireSpan(start=151, length=168, text='\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\nComparison of Non-Human Primate and Human Whole Blood Tissue Gene Expression Profiles '), HighwireSpan(start=322, length=41, text='\r\n\r\ndoi:10.1093/toxsci/kfi243 '), HighwireSpan(start=366, length=68, text='\r\n\r\nToxicological Sciences 87, 306\x96314, 2005 '), HighwireSpan(start=437, length=719, text='\r\n\r\nIn our paper "Comparison of non-human primate and human whole blood tissue gene expression profiles" which was published ahead of print on June 23, 2005 (doi:10.1093/toxscikfi243) and is printed in the September 2005 issue of the journal (Toxicol. Sci. 84: 306\x96314) we reference the work of Wang et al. 2004. Their paper, entitled "Identification and utilization of inter-species conserved (ISC) probesets on Affymetrix human Genechip platforms for the optimization of the assessment of expression patterns in non human primate (NHP) samples" was published in BMC Bioinformatics 5, 165, 2004. '), HighwireSpan(start=1159, length=382, text="\r\n\r\nAlthough we cite Wang et al. 2004 in our introduction and discussion, we failed to give appropriate attribution to text in our discussion taken from that paper. We sincerely regret our failure to properly cite these authors' work and wish to correct this by attributing the following text in our discussion to them: "), HighwireSpan(start=1544, length=223, text='\r\n\r\nA single gene does not necessarily generate a single transcript. Splicing variants are very common in the human, and humans and NHPs may use different splicing strategies in some genes. '), HighwireSpan(start=1770, length=893, text='\r\n\r\nChismar and colleagues used the U95Av2 human genechip and compared the expression patterns of humans with rhesus. They concluded that the percentage of detected genes (genes called \x91present\x92) in the rhesus brain is lower than that of human brain, and that this is especially true for genes with lower signal intensity. Caceres and colleagues used the HG-U95Av2 human genechip to identify upregulated genes in the human cortex compared with those of the NHPs. Since sequence divergence could lead to an underestimation of expression levels in NHPs, they excluded 4572 probes that exhibited different hybridization behavior between two sets of samples in order to reduce false positives. However, this analysis is solely based on probe intensities. '), HighwireSpan(start=2666, length=12162, text="\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\t\r\n        \r\n        \r\n\t\r\n\t\r\n\t\r\n\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n \r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n  \r\n  \r\n  \r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\t \r\n\t\t\r\n\t\t  \r\n\t\t\t\r\n\t\r\n\t\t\r\n\t\t\t\r\n\t\t\t\r\n\t\r\n\r\n\r\n\t\r\n\r\n\r\n\t\r\n\t\t\r\n\r\n\r\n\r\n\r\n\t\r\n\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\t\t\r\n\t\t\t\r\n\t\t\t\r\nThis Article\r\n\t\r\n\t\t\t\t\r\n\t\t\r\n\t\t\t\t\t\r\n\t\t\t\t\t\t\r\n\t\t\t\t\t\r\n\t\t\t\t\t\r\n\t\t\t\t\tExtract\r\n\t\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\r\n\t\t\t\r\n\t\t\r\n\t\t\r\n\t\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\t\r\n\t\r\n\t\r\n\t\t\r\n\t\r\n\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\t\t\r\n\t\t\r\n\t\r\n\r\n\t\r\n\r\n\t\r\n\t \r\n\r\n\t\r\n\t \r\n\r\n\t\t\r\n\t\t\r\n\t\t\r\n\t\t\r\n\t\t\r\n\t\t\r\n\t\t\t\r\n\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\t\t\r\n\t\tFull Text (PDF)\r\n\t\t\t\t\r\n\t\t\t\r\n\t\t\r\n\t\t\r\n\t\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\t\t\r\n\r\n\t\r\n\t\t\r\n\r\n\t\r\n\t\t\r\n\t\t\r\n\r\n\t\t\t\r\n\r\n\r\n\t\r\n\r\n\t\t\t\r\n\r\n\t\t\t\r\n\t\t\r\n\t\r\n\r\n\t\t\t\r\n\t  \r\n\t\r\n\r\n\t\t\t\r\n\r\n\t\t\t\r\n\r\n\t\t\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\t\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\t\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\r\n\r\n\t \r\n\r\n\t\r\n\r\n\t\r\n\t\r\n\t\t  \r\n    \r\n\r\n\t\r\n\t\r\n\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\t\r\n\t\r\n\t\t\r\n\t\t\t\r\n\t\t\r\n\t\t\t\t\r\n\t\t\t\tAlert me when this article is cited\r\n\t\t\t\r\n\t\r\n\r\n\t\t\r\n\t\t\r\n\r\n\t\t\r\n\t\t\r\n\r\n\t\t\r\n\t\t\r\n\r\n\t\t\t\r\n\t\t\r\n\t\t\t\t\r\n\t\t\t\tAlert me if a correction is posted\r\n\t\t\t\r\n\t\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\t\t\r\n\t\t\r\n\t\r\n\r\n\t\t\t\r\n\t\t\t\r\nServices\r\n\t\r\n\t\t\t\r\n\t\t\r\n\t\t\t\t\r\n\t\t\t\tEmail this article to a friend\r\n\t\t\t\r\n\t\t\t\r\n\t\t\t\r\n\r\n\r\n\t\r\n\r\n\t\r\n\r\n\t\t\r\n\t\t\r\n\r\n\r\n\r\n\t\t\t\r\n\t\t\t\r\n\t\t\t\r\n\t\t\r\n\t\r\n\r\n\t\t\r\n\t\t\r\n\t\t\r\n\t\t\r\n\t\tSimilar articles in this journal\r\n\t\t\r\n\t\t\r\n\r\n\t\t\r\n\t\t\r\n\r\n\t\t\t\r\n\t\t\r\n\t\t\t\t\r\n\t\t\t\tSimilar articles in PubMed\r\n\t\t\t\r\n\t\t\r\n\t\r\n\r\n\r\n\t\t\r\n\r\n\r\n\r\n\t\t\t\r\n\t\t\r\n\t\t\t\t\r\n\t\t\t\tAlert me to new issues of the journal\r\n\t\t\t\r\n\t\t\r\n\r\n\t\t\r\n\t\t\r\n\t\t\r\n\r\n\t\t\t\r\n\t\t\r\n\t\t\t\t\r\n\t\t\t\tAdd to My Personal Archive\r\n\t\t\t\r\n\t\t\r\n\t\t\r\n\t\r\n\r\n\t\t\r\n\t\t\r\n\t\t\r\n\r\n\t\t\t\r\n\t\t\r\n\t\t\t\r\n\t\t\tDownload to citation manager\r\n\t\t\t\r\n\t\t\r\n\t\t\r\n\t\r\n\r\n\r\n\t\r\n\t\t\r\n\t\r\n\r\n\t\r\n\r\n\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\t\r\n\r\n\t\t\r\n\r\n\t\r\n\t\r\n\t\r\n\t\t\r\n\r\n\t\t\t\r\n\t\t\r\n\t\t\t\tDisclaimer\r\n\t\t\t\r\n\t\t\r\n\r\n\t\r\n\t\t\r\n\r\n\t\t\r\n\t\t\r\n\t\t\t\r\n\t\t\tRequest Permissions\r\n\t\t\r\n\t\t\r\n\t\r\n\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\t\t\r\n\t\t\t\r\n\t\t\t\t\r\n\t\t\t\t\r\nGoogle Scholar\r\n\t\r\n\t\t\t\t\t\t\r\n\t\t\r\n\t\t\t\t\t\t\t\r\n\t\t\t\t\t\t\tArticles by Dillman, J. F.\r\n\t\t\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\r\n\t\t\t\t\r\n\t\t\t\t\r\n\r\n\t\t\t\t\t\t\r\n\t\t\r\n\t\t\t\t\t\t\t\r\n\t\t\t\t\t\t\tArticles by Phillips, C. S.\r\n\t\t\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\r\n\t\t\r\n\t\t\r\n\t\r\n\t\r\n\t\r\n\t\t\r\n\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\t\t\r\nPubMed\r\n\t\r\n\t\t\t\r\n\t\t\r\n\t\t\t\tPubMed Citation\r\n\t\t\t\r\n\t\t\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\t\r\n\t\t\t\r\n\t\t\t\t\r\n\r\n\t\t\t\t\t\t\r\n\t\t\r\n\t\t\t\t\t\t\t\r\n\t\t\t\t\t\t\tArticles by Dillman, J. F., III\r\n\t\t\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\r\n\t\t\t\t\r\n\r\n\t\t\t\t\t\t\r\n\t\t\r\n\t\t\t\t\t\t\t\r\n\t\t\t\t\t\t\tArticles by Phillips, C. S.\r\n\t\t\t\t\t\t\r\n\t\t\t\t\r\n\t\t\t\r\n\t\t\r\n\r\n\t\t\r\n\t\r\n\r\n\t\r\n\t\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\t\t\r\n\r\n\t\r\n\r\n\t\t\r\n\t\t\t\r\n\t\t\r\n\t \r\n\t\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\r\n\r\n\r\n\r\n\t\r\n \r\n\r\n\t\t\t\t\t\r\n\t\t\t\t\t\r\n\t\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\t\r\n\r\n\r\n\r\n\r\nOnline ISSN 1096-0929 - Print ISSN 1096-6080\r\n\r\n\r\nCopyright © 2005 Society of Toxicology\r\n\r\n\r\n\r\n\r\nOxford Journals\r\nOxford University Press\r\n\r\n\r\n\r\nSite Map\r\n\r\nPrivacy Policy\r\nFrequently Asked Questions\r\n\r\n\r\n\r\n\r\n\r\nOther Oxford University Press sites:\r\n\r\nOxford University Press\r\nAmerican National Biography\r\nBooksellers' Information Service\r\nChildren's Fiction and Poetry\r\nChildren's Reference\r\nCorporate & Special Sales\r\nDictionaries\r\nDictionary of National Biography\r\nDigital Reference\r\nEnglish Language Teaching\r\nHigher Education Textbooks\r\nHumanities\r\nInternational Education Unit\r\nLaw\r\nMedicine\r\nMusic\r\nOnline Products\r\nOxford English Dictionary\r\nReference\r\nRights and Permissions\r\nScience\r\nSchool Books\r\nSocial Sciences\r\nVery Short Introductions\r\nWorld's Classics\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n\r\n"))),
        })

    
    def test_highwire_queries(self):
        self._test_queries('highwire/trec-genomics-2006', count=28, items={
            0: GenericQuery('160', 'What is the role of PrnP in mad cow disease?'),
            1: GenericQuery('161', 'What is the role of IDE in Alzheimer’s disease'), # testing windows encoding here with curly apos
            9: GenericQuery('169', 'How does APC (adenomatous polyposis coli) protein affect actin assembly'),
            27: GenericQuery('187', 'How do  mutations in familial hemiplegic migraine type 1 (FHM1) gene affect calcium ion influx in hippocampal neurons?'),
        })
        self._test_queries('highwire/trec-genomics-2007', count=36, items={
            0: GenericQuery('200', 'What serum proteins change expression in association with high disease activity in lupus?'),
            9: GenericQuery('209', 'What biological substances have been used to measure toxicity in response to etidronate?'),
            35: GenericQuery('235', 'Which genes involved in NFkappaB signaling regulate iNOS?'),
        })

    def test_highwire_qrels(self):
        self._test_qrels('highwire/trec-genomics-2006', count=27999, items={
            0: HighwireQrel('160', '11152658', 42431, 2100, 0),
            9: HighwireQrel('160', '12519913', 61139, 1786, 0),
            27998: HighwireQrel('187', '16103228', 8974, 3974, 0),
        })
        self._test_qrels('highwire/trec-genomics-2007', count=35996, items={
            0: HighwireQrel('200', '7493960', 39964, 2283, 0),
            9: HighwireQrel('200', '8996242', 5373, 1092, 0),
            35995: HighwireQrel('235', '16339966', 117520, 519, 0),
        })


if __name__ == '__main__':
    unittest.main()
